
#include-once

;### MathExPLA_RightAngleTriange_GetLengthFromAB ###########################################################################
;Syntax ..................: MathExPLA_RightAngleTriange_GetLengthFromAB($a, $b)
;Beschreibung ............: Gibt die unbekannte Seitenlnge c eines rechtwinkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;							$b					Die Seitenlnge b des Dreiecks
;Rckgabe ................: Erfolg:				Die Seitenlnge c
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_RightAngleTriange_GetLengthFromAB($a, $b)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt($a*$a+$b*$b)
EndFunc ;==> MathExPLA_RightAngleTriange_GetLengthFromAB

;### MathExPLA_RightAngleTriange_GetLengthFromBC ###########################################################################
;Syntax ..................: MathExPLA_RightAngleTriange_GetLengthFromBC($b, $c)
;Beschreibung ............: Gibt die unbekannte Seitenlnge a eines rechtwinkligen Dreiecks zurck
;Variablen ...............: $b					Die Seitenlnge b des Dreiecks
;							$c					Die Seitenlnge c des Dreiecks
;Rckgabe ................: Erfolg:				Die Seitenlnge a
;							Fehler:				0, setzt @error
;							@error:				1 	$b ist keine Zahl
;												2 	$c ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_RightAngleTriange_GetLengthFromBC($b, $c)
   If Not IsNumber($b) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt($c*$c-$b*$b)
EndFunc ;==> MathExPLA_RightAngleTriange_GetLengthFromBC

;### MathExPLA_RightAngleTriange_GetLengthFromAC ###########################################################################
;Syntax ..................: MathExPLA_RightAngleTriange_GetLengthFromAC($a, $c)
;Beschreibung ............: Gibt die unbekannte Seitenlnge b eines rechtwinkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;							$c					Die Seitenlnge c des Dreiecks
;Rckgabe ................: Erfolg:				Die Seitenlnge b
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$c ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_RightAngleTriange_GetLengthFromAC($a, $c)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt($c*$c-$a*$a)
EndFunc ;==> MathExPLA_RightAngleTriange_GetLengthFromAC

;### MathExPLA_RightAngleTriange_GetSurface ################################################################################
;Syntax ..................: MathExPLA_RightAngleTriange_GetSurface($a, $b)
;Beschreibung ............: Gibt die Oberflche eines rechtwinkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;							$b					Die Seitenlnge b des Dreiecks
;Rckgabe ................: Erfolg:				Die Oberflche des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_RightAngleTriange_GetSurface($a, $b)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   Return ($a*$b)/2
EndFunc ;==> MathExPLA_RightAngleTriange_GetSurface

;### MathExPLA_EquiangularTriangle_GetHeight ###############################################################################
;Syntax ..................: MathExPLA_EquiangularTriangle_GetHeight($a)
;Beschreibung ............: Gibt die Hhe eines gleichwinkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;Rckgabe ................: Erfolg:				Die Hhe des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_EquiangularTriangle_GetHeight($a)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   Return $a/2*Sqrt(3)
EndFunc ;==> MathExPLA_EquiangularTriangle_GetHeight

;### MathExPLA_EquiangularTriangle_GetSurface ##############################################################################
;Syntax ..................: MathExPLA_EquiangularTriangle_GetSurface($a, $Height)
;Beschreibung ............: Gibt die Oberflche eines gleichwinkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;							$Height				Die Hhe des Dreiecks
;Rckgabe ................: Erfolg:				Die Oberflche des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$Height ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_EquiangularTriangle_GetSurface($a, $Height)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return ($a*$a)*Sqrt(3)/4
EndFunc ;==> MathExPLA_EquiangularTriangle_GetSurface

;### MathExPLA_EquiangularTriangle_GetSCircumference #######################################################################
;Syntax ..................: MathExPLA_EquiangularTriangle_GetSCircumference($a)
;Beschreibung ............: Gibt den Umfang eines gleichwinkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;Rckgabe ................: Erfolg:				Der Umfang des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_EquiangularTriangle_GetSCircumference($a)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   Return 3*$a
EndFunc ;==> MathExPLA_EquiangularTriangle_GetSCircumference

;### MathExPLA_IsoscelesTriangle_GetSurface ################################################################################
;Syntax ..................: MathExPLA_IsoscelesTriangle_GetSurface($a)
;Beschreibung ............: Gibt die Flche eines gleichschenkligen Dreiecks zurck
;Variablen ...............: $b					Die Seitenlnge b des Dreiecks
;							$Height				Die Hhe des Dreiecks
;Rckgabe ................: Erfolg:				Die Flche des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$b ist keine Zahl
;												2	$Height ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_IsoscelesTriangle_GetSurface($b, $Height)
   If Not IsNumber($b) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 1/2*$b*$Height
EndFunc ;==> MathExPLA_IsoscelesTriangle_GetSurface

;### MathExPLA_IsoscelesTriangle_GetHeight #################################################################################
;Syntax ..................: MathExPLA_IsoscelesTriangle_GetHeight($a)
;Beschreibung ............: Gibt die Hhe eines gleichschenkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlngen a des Dreiecks
;							$b					Die Seitenlnge b des Dreiecks
;Rckgabe ................: Erfolg:				Die Hhe des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$b ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_IsoscelesTriangle_GetHeight($a, $b)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt(($a*$a)-($b*$b)/4)
EndFunc ;==> MathExPLA_IsoscelesTriangle_GetHeight

;### MathExPLA_IsoscelesTriangle_GetCircumference ##########################################################################
;Syntax ..................: MathExPLA_IsoscelesTriangle_GetHeight($a)
;Beschreibung ............: Gibt den Umfang eines gleichschenkligen Dreiecks zurck
;Variablen ...............: $a					Die Seitenlngen a des Dreiecks
;							$b					Die Seitenlnge b des Dreiecks
;Rckgabe ................: Erfolg:				Der Umfang des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$b ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_IsoscelesTriangle_GetCircumference($a, $b)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 2*$a+$b
EndFunc ;==> MathExPLA_IsoscelesTriangle_GetCircumference

;### MathExPLA_Triange_GetCircumference ####################################################################################
;Syntax ..................: MathExPLA_Triange_GetCircumference($a, $b, $c)
;Beschreibung ............: Gibt den Umfang eines Dreiecks zurck
;Variablen ...............: $a					Die Seitenlnge a des Dreiecks
;							$b					Die Seitenlnge b des Dreiecks
;							$c					Die Seitenlnge c des Dreiecks
;Rckgabe ................: Erfolg:				Der Umfang des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;												3	$c ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_Triange_GetCircumference($a, $b, $c)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(3)
	  Return 0
   EndIf
   Return $a+$b+$c
EndFunc ;==> MathExPLA_RightAngleTriange_GetCircumference

;### MathExPLA_Triangle_GetAngle ###########################################################################################
;Syntax ..................: MathExPLA_Triangle_GetAngle($Angle1, $Angle2)
;Beschreibung ............: Gibt einen Fehlenden Winkel von einem Dreieck zurck
;Variablen ...............: $Angle1				Der erste bekannte Winkel des Dreiecks
;							$Angle2				Der zweite bekannte Winkel des Dreiecks
;Rckgabe ................: Erfolg:				Der unbekannte Winkel des Dreiecks
;							Fehler:				0, setzt @error
;							@error:				1 	$Angle1 ist keine Zahl
;												2 	$Angle2 ist keine Zahl
;Bemerkungen .............: Siehe MathEx_Trigonometrics fr weitere Funktionen fr Dreiecke
;###########################################################################################################################
Func MathExPLA_Triangle_GetAngle($Angle1, $Angle2)
   If Not IsNumber($Angle1) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Angle2) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 180-$Angle1-$Angle2
EndFunc ;==> MathExPLA_Triangle_GetAngle

;### MathExPLA_Square_GetSurface ###########################################################################################
;Syntax ..................: MathExPLA_Square_GetSurface($Width, $Height)
;Beschreibung ............: Gibt die Flche eines Quadrates zurck
;Variablen ...............: $Width				Die Breite des Quadrats
;							$Height				Die Hhe des Quadrats
;Rckgabe ................: Erfolg:				Die Flche des Quadrates
;							Fehler:				0, setzt @error
;							@error:				1 	$Width ist keine Zahl
;												2 	$Height ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Square_GetSurface($Width, $Height)
   If Not IsNumber($Width) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return $Width*$Height
EndFunc ;==> MathExPLA_Square_GetSurface

;### MathExPLA_Square_GetCircumference #####################################################################################
;Syntax ..................: MathExPLA_Square_GetCircumference($Width, $Height)
;Beschreibung ............: Gibt den Umfang eines Quadrates zurck
;Variablen ...............: $Width				Die Breite des Quadrats
;							$Height				Die Hhe des Quadrats
;Rckgabe ................: Erfolg:				Der Umfang des Quadrates
;							Fehler:				0, setzt @error
;							@error:				1 	$Width ist keine Zahl
;												2 	$Height ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Square_GetCircumference($Width, $Height)
   If Not IsNumber($Width) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 2*($Width+$Height)
EndFunc ;==> MathExPLA_Square_GetCircumference

;### MathExPLA_Square_GetDiagonal ##########################################################################################
;Syntax ..................: MathExPLA_Square_GetDiagonal($Width, $Height)
;Beschreibung ............: Gibt die Lnge der Diagonalen eines Quadrates zurck
;Variablen ...............: $Width				Die Breite des Quadrats
;							$Height				Die Hhe des Quadrats
;Rckgabe ................: Erfolg:				Die Lnge der Diagonalen des Quadrates
;							Fehler:				0, setzt @error
;							@error:				1 	$Width ist keine Zahl
;												2 	$Height ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Square_GetDiagonal($Width, $Height)
   If Not IsNumber($Width) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(2)
	  Return 0
   EndIf
   Return Sqrt($Width*$Width+$Height*$Height)
EndFunc ;==> MathExPLA_Square_GetDiagonal

;### MathExPLA_Parallelogram_GetSurface ####################################################################################
;Syntax ..................: MathExPLA_Parallelogram_GetSurface($a, $b, $Alpha)
;Beschreibung ............: Gibt die Oberflche eines Parallelogramms zurck
;Variablen ...............: $a					Die Seitenlnge a (unten)
;							$b					Die Seitenlnge b (rechts)
;							$Alpha				Der Winkel des Parallelogramms (unten links)
;Rckgabe ................: Erfolg:				Die Oberflche des Parallelograms
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;												3	$Alpha ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Parallelogram_GetSurface($a, $b, $Alpha)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Alpha) Then
	  SetError(3)
	  Return 0
   EndIf
   Return $a*$b*Sin($Alpha*$MATHEX_CONST_RADIAN)
EndFunc ;==> MathExPLA_Parallelogram_GetSurface

;### MathExPLA_Parallelogram_GetCircumference ##############################################################################
;Syntax ..................: MathExPLA_Parallelogram_GetCircumference($a, $b)
;Beschreibung ............: Gibt den Umfang eines Parallelogramms zurck
;Variablen ...............: $a					Die Seitenlnge a (unten)
;							$b					Die Seitenlnge b (rechts)
;Rckgabe ................: Erfolg:				Der Umfang des Parallelogramms
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Parallelogram_GetCircumference($a, $b)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 2*($a+$b)
EndFunc;==> MathExPLA_Parallelogram_GetCircumference

;### MathExPLA_Trapeze_GetSurface ##########################################################################################
;Syntax ..................: MathExPLA_Trapeze_GetSurface($a, $c, $Height)
;Beschreibung ............: Gibt die Flche eines Trapez zurck
;Variablen ...............: $a					Die Seitenlnge a (unten)
;							$c					Die Seitenlnge c (oben)
;							$Height				Die Hhe des Trapez
;Rckgabe ................: Erfolg:				Die Flche des Trapez
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$c ist keine Zahl
;												3 	$Height ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Trapeze_GetSurface($a, $c, $Height)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($Height) Then
	  SetError(3)
	  Return 0
   EndIf
   Return 1/2*($a+$c)*$Height
EndFunc ;==> MathExPLA_Trapeze_GetSurface

;### MathExPLA_Trapeze_GetCircumference ####################################################################################
;Syntax ..................: MathExPLA_Trapeze_GetCircumference($a, $b, $c, $d)
;Beschreibung ............: Gibt den Umfang eines Trapez zurck
;Variablen ...............: $a					Die Seitenlnge a (unten)
;							$b					Die Seitenlnge b (rechts)
;							$c					Die Seitenlnge c (oben)
;							$d					Die Seitenlnge d (links)
;Rckgabe ................: Erfolg:				Der Umfang des Trapez
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2 	$b ist keine Zahl
;												3 	$c ist keine Zahl
;												4 	$d ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Trapeze_GetCircumference($a, $b, $c, $d)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($b) Then
	  SetError(2)
	  Return 0
   EndIf
   If Not IsNumber($c) Then
	  SetError(3)
	  Return 0
   EndIf
   If Not IsNumber($d) Then
	  SetError(4)
	  Return 0
   EndIf
   Return $a+$b+$c+$d
EndFunc ;==> MathExPLA_Trapeze_GetCircumference

;### MathExPLA_Circle_GetDiameter ##########################################################################################
;Syntax ..................: MathExPLA_Circle_GetDiameter($Radius)
;Beschreibung ............: Gibt den Durchmesser eines Kreises zurck
;Variablen ...............: $Radius				Der Radius des Kreises
;Rckgabe ................: Erfolg:				Der Durchmesserdes Kreises
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Circle_GetDiameter($Radius)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   Return 2*$Radius
EndFunc ;==> MathExPLA_Circle_GetDiameter

;### MathExPLA_Circle_GetSurface ###########################################################################################
;Syntax ..................: MathExPLA_Circle_GetSurface($Radius)
;Beschreibung ............: Gibt die Flche eines Kreises zurck
;Variablen ...............: $Radius				Der Radius des Kreises
;Rckgabe ................: Erfolg:				Die Flche des Kreises
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Circle_GetSurface($Radius)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   Return ($Radius*$Radius)*$MATHEX_CONST_PI
EndFunc ;==> MathExPLA_Circle_GetSurface

;### MathExPLA_Circle_GetCircumference #####################################################################################
;Syntax ..................: MathExPLA_Circle_GetCircumference($Radius)
;Beschreibung ............: Gibt den Umfang eines Kreises zurck
;Variablen ...............: $Radius				Der Radius des Kreises
;Rckgabe ................: Erfolg:				Der Umfang des Kreises
;							Fehler:				0, setzt @error
;							@error:				1 	$Radius ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Circle_GetCircumference($Radius)
   If Not IsNumber($Radius) Then
	  SetError(1)
	  Return 0
   EndIf
   Return 2*$Radius*$MATHEX_CONST_PI
EndFunc ;==> MathExPLA_Circle_GetCircumference

;### MathExPLA_Circle_GetCoordinate ########################################################################################
;Syntax ..................: MathExPLA_Circle_GetDiameterCoord($Diameter, $Degree)
;Beschreibung ............: Gibt eine bestimmte Koordinate eines Kreises anhand eines Winkels zurck
;Variablen ...............: $Diameter			Der Durchmesser des Kreises
;							$Degree				Der Winkel des Punktes auf dem Kreis (0 - 360)
;Rckgabe ................: Erfolg:				Ein 1-dimensionales Array mit den Koordinaten ([0] = x, [1] = y)
;							Fehler:				0, setzt @error
;							@error:				1 	$Diameter ist keine Zahl
;												2	$Degree ist keine Zahl oder kleiner als 0 oder grer als 360
;Bemerkungen .............: Siehe auch MathEx2DS_SingleCircle
;###########################################################################################################################
Func MathExPLA_Circle_GetCoordinate($Diameter, $Degree)
   If Not IsNumber($Diameter) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Degree) Or $Degree < 0 Or $Degree > 360 Then
	  SetError(2)
	  Return 0
   EndIf
   Dim $return[2]
   $Radius = $Diameter/2
   $return[1] = (Sin($MATHEX_CONST_RADIAN*$degree)*$Radius)
   $return[0] = (Cos($MATHEX_CONST_RADIAN*$degree)*$Radius)
   Return $return
EndFunc ;==> MathExPLA_Circle_GetCoordinate

;### MathExPLA_Rhombus_GetSurface ########################################################################################
;Syntax ..................: MathExPLA_Rhombus_GetSurface($a, $Alpha)
;Beschreibung ............: Gibt die Oberflche einer Raute zurck
;Variablen ...............: $a					Die Seitenlnge a der Raute
;							$Alpha				Der Winkel Alpha der Raute
;Rckgabe ................: Erfolg:				Die Oberflche der Raute
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$Alpha ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Rhombus_GetSurface($a, $Alpha)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Alpha) Then
	  SetError(2)
	  Return 0
   EndIf
   Return $a*$a*Sin($Alpha*$MATHEX_CONST_RADIAN)
EndFunc ;==> MathExPLA_Rhombus_GetSurface

;### MathExPLA_Rhombus_GetCircumference ########################################################################################
;Syntax ..................: MathExPLA_Rhombus_GetCircumference($a)
;Beschreibung ............: Gibt den Umfang einer Raute zurck
;Variablen ...............: $a					Die Seitenlnge a der Raute
;Rckgabe ................: Erfolg:				Der Umfang der Raute
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Rhombus_GetCircumference($a)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   Return $a*4
EndFunc ;==> MathExPLA_Rhombus_GetCircumference

;### MathExPLA_Rhombus_GetDiagonal1 ########################################################################################
;Syntax ..................: MathExPLA_Rhombus_GetDiagonal1($a, $Alpha)
;Beschreibung ............: Gibt die Lnge der ersten Diagonale einer Raute zurck
;Variablen ...............: $a					Die Seitenlnge a der Raute
;							$Alpha				Der Winkel Alpha der Raute
;Rckgabe ................: Erfolg:				Die Lnge der ersten Diagonale der Raute
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$Alpha ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Rhombus_GetDiagonal1($a, $Alpha)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Alpha) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 2*$a*Cos($Alpha/2)
EndFunc ;==> MathExPLA_Rhombus_GetDiagonal1

;### MathExPLA_Rhombus_GetDiagonal2 ########################################################################################
;Syntax ..................: MathExPLA_Rhombus_GetDiagonal1($a, $Alpha)
;Beschreibung ............: Gibt die Lnge der zweiten Diagonale einer Raute zurck
;Variablen ...............: $a					Die Seitenlnge a der Raute
;							$Alpha				Der Winkel Alpha der Raute
;Rckgabe ................: Erfolg:				Die Lnge der zweiten Diagonale der Raute
;							Fehler:				0, setzt @error
;							@error:				1 	$a ist keine Zahl
;												2	$Alpha ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Rhombus_GetDiagonal2($a, $Alpha)
   If Not IsNumber($a) Then
	  SetError(1)
	  Return 0
   EndIf
   If Not IsNumber($Alpha) Then
	  SetError(2)
	  Return 0
   EndIf
   Return 2*$a*Sin(($Alpha/2)*$MATHEX_CONST_RADIAN)
EndFunc ;==> MathExPLA_Rhombus_GetDiagonal2

;### MathExPLA_Rhombus_GetAngle ############################################################################################
;Syntax ..................: MathExPLA_Rhombus_GetAngle($Angle)
;Beschreibung ............: Gibt den zweiten, fehlenden Winkel zurck
;Variablen ...............: $Angle				Der bekannte Winkel
;Rckgabe ................: Erfolg:				Der zweite, fehlende Winkel
;							Fehler:				0, setzt @error
;							@error:				1 	$Angle ist keine Zahl
;###########################################################################################################################
Func MathExPLA_Rhombus_GetAngle($Angle)
   If Not IsNumber($Angle) Then
	  SetError(1)
	  Return 0
   EndIf
   Return 180-$Angle
EndFunc ;==> MathExPLA_Rhombus_GetAngle

;### MathExPLA_NGon_InnerAngleSum ##########################################################################################
;Syntax ..................: MathExPLA_Ngon_InnerAngleSum($N)
;Beschreibung ............: Gibt die Summer der Innenwinkel eines N-ecks zurck
;Variablen ...............: $N					Die Anzahl der Ecken
;Rckgabe ................: Erfolg:				Die Summer der Innenwinkel eines N-ecks
;							Fehler:				0, setzt @error
;							@error:				1 	$N ist keine Zahl
;###########################################################################################################################
Func MathExPLA_NGon_InnerAngleSum($N)
   If Not IsNumber($N) Then
	  SetError(1)
	  Return 0
   EndIf
   Return ($N-2)*180
EndFunc

;### MathExPLA_NGon_InnerRegularAngle ##########################################################################################
;Syntax ..................: MathExPLA_Ngon_InnerAngle($N)
;Beschreibung ............: Gibt den Innenwinkel eines regelmigen N-ecks zurck
;Variablen ...............: $N					Die Anzahl der Ecken
;Rckgabe ................: Erfolg:				Der Innenwinkel eines regelmigen N-ecks
;							Fehler:				0, setzt @error
;							@error:				1 	$N ist keine Zahl
;###########################################################################################################################
Func MathExPLA_NGon_InnerRegularAngle($N)
   If Not IsNumber($N) Then
	  SetError(1)
	  Return 0
   EndIf
   Return MathExPLA_NGon_InnerAngleSum($N)/$N
EndFunc

;### MathExPLA_NGon_OuterAngleSum ##########################################################################################
;Syntax ..................: MathExPLA_NGon_OuterAngleSum($N)
;Beschreibung ............: Gibt die Summer der Auenwinkel eines N-ecks zurck
;Variablen ...............: $N					Die Anzahl der Ecken
;Rckgabe ................: Erfolg:				Die Summer der Auenwinkel eines N-ecks
;							Fehler:				0, setzt @error
;							@error:				1 	$N ist keine Zahl
;###########################################################################################################################
Func MathExPLA_NGon_OuterAngleSum($N)
   If Not IsNumber($N) Then
	  SetError(1)
	  Return 0
   EndIf
   Return ($N+2)*180
EndFunc

;### MathExPLA_NGon_OuterRegularAngle ##########################################################################################
;Syntax ..................: MathExPLA_Ngon_InnerAngle($N)
;Beschreibung ............: Gibt den Auenwinkel eines regelmigen N-ecks
;Variablen ...............: $N					Die Anzahl der Ecken
;Rckgabe ................: Erfolg:				Der Auenwinkel eines regelmigen N-ecks
;							Fehler:				0, setzt @error
;							@error:				1 	$N ist keine Zahl
;###########################################################################################################################
Func MathExPLA_NGon_OuterRegularAngle($N)
   If Not IsNumber($N) Then
	  SetError(1)
	  Return 0
   EndIf
   Return MathExPLA_NGon_OuterAngleSum($N)/$N
EndFunc